@@ -5,20 +5,25 @@ import json
 import pprint
 import uuid
 
-__version__ = '2.4.0'
+__branch__ = "dos"
+__version__ = '2.5.0'
 
 class HorsemeatJSONEncoder(json.JSONEncoder):
 
     def default(self, obj):
 
+        # TODO: when something can not be JSON-encoded, just return a
+        # message like "can not JSON-encode {0}".
+
         import psycopg2.extras
 
         # Any object that wants to be encoded into JSON should make a
-        # property called __json__data that spits out some dictionary.
+        # property called __jsondata__ that spits out something that can
+        # be JSON-encoded.
         if hasattr(obj, '__jsondata__'):
             return obj.__jsondata__
 
-        # this is how we handle datetimes and dates.
+        # This is to handle datetimes and dates.
         elif hasattr(obj, 'isoformat') and callable(obj.isoformat):
             return obj.isoformat()
 
@@ -35,6 +40,7 @@ class HorsemeatJSONEncoder(json.JSONEncoder):
             return json.JSONEncoder.default(self, obj)
 
 
+# TODO: add a docstring on this guy.
 fancyjsondumps = functools.partial(
     json.dumps,
     cls=HorsemeatJSONEncoder,
